﻿/**
 * @name umi 的路由配置
 * @description 只支持 path,component,routes,redirect,wrappers,name,icon 的配置
 * @param path  path 只支持两种占位符配置，第一种是动态参数 :id 的形式，第二种是 * 通配符，通配符只能出现路由字符串的最后。
 * @param component 配置 location 和 path 匹配后用于渲染的 React 组件路径。可以是绝对路径，也可以是相对路径，如果是相对路径，会从 src/pages 开始找起。
 * @param routes 配置子路由，通常在需要为多个路径增加 layout 组件时使用。
 * @param redirect 配置路由跳转
 * @param wrappers 配置路由组件的包装组件，通过包装组件可以为当前的路由组件组合进更多的功能。 比如，可以用于路由级别的权限校验
 * @param name 配置路由的标题，默认读取国际化文件 menu.ts 中 menu.xxxx 的值，如配置 name 为 login，则读取 menu.ts 中 menu.login 的取值作为标题
 * @param icon 配置路由的图标，取值参考 https://ant.design/components/icon-cn， 注意去除风格后缀和大小写，如想要配置图标为 <StepBackwardOutlined /> 则取值应为 stepBackward 或 StepBackward，如想要配置图标为 <UserOutlined /> 则取值应为 user 或者 User
 * @doc https://umijs.org/docs/guides/routes
 */
export default [
  {
    path: '/Welcome',
    routes: [
      {
        name: 'Welcome',
        path: '/Welcome',
        hideInMenu: true,
        component: './system/welco',
      },
    ],
  },
  {
    path: '/login',
    layout: false,
    routes: [
      {
        name: 'login',
        path: '/login',
        component: './Login',
      },
    ],
  },
  {
    name: '统计分析',
    path: '/statistics',
    component: './statistics/index',
    // access: '/system_setting/position_management',
  },
  {
    path: '/setting',
    // layout: false,
    name: '系统设置',
    access: '/system_setting',
    routes: [
      {
        name: '职位管理',
        path: '/setting/career',
        component: './setting/career/index',
        access: '/system_setting/position_management',
      },
      {
        name: '权限管理',
        path: '/setting/role',
        component: './setting/role',
        access: '/system_setting/role_management',
      },
      {
        name: '人员管理',
        path: '/setting/user',
        component: './setting/user',
        access: '/system_setting/people_management',
      }
    ],
  },
  {
    path: '/work-order',
    // layout: false,
    name: '工单事项管理',
    access: '/work_order_transaction_management',
    routes: [
      {
        name: '工单事项配置',
        path: '/work-order/configuration',
        component: './work-order-setting/index',
        access: '/work_order_transaction_management/work_order_item_configuration',
      },
      {
        name: '问题类型管理',
        path: '/work-order/problemType',
        component: './work-order/problem-type/index',
        access: '/work_order_transaction_management/problem_type_management',
      },
      {
        name: 'banner管理',
        path: '/work-order/banner',
        component: './work-order/banner/index',
        access: '/work_order_transaction_management/banner_management',
      },
    ],
  },
  {
    path: '/party',
    // layout: false,
    name: '党员管理',
    access: '/party_member',
    routes: [
      {
        name: '党员管理',
        path: '/party/manage',
        component: './party/manage/index',
        access: '/party_member/list',
      },
      {
        name: '添加党员',
        path: '/party/manage/add',
        hideInMenu: true,
        component: './party/manage/components/addAndEdit',
        // access: '/work_order_transaction_management/problem_type_management',
      },
      {
        name: '党员审核',
        path: '/party/audit',
        component: './party/audit/index',
        access: '/party_member_audit/list',
      },
    ],
  },
  {
    path: '/message-notification',
    // layout: false,
    name: '消息通知',
    access: '/message_notification',
    routes: [
      {
        name: '消息通知',
        path: '/message-notification/list',
        component: './message-notification/index',
        access: '/message_notification',
      },
    ],
  },
  {
    path: '/appeal-management',
    // layout: false,
    name: '诉求管理',
    access: '/complaint',
    routes: [
      {
        name: '诉求管理',
        path: '/appeal-management/list',
        component: './appeal-management/index',
        access: '/complaint/list',
      },
      {
        name: '述求详情',
        path: '/appeal-management/detail',
        component: './appeal-management/detail',
        access: '/message_notification',
        hideInMenu: true,
      },
      {
        name: '问题驳回统计',
        path: '/appeal-management/statistics',
        component: './appeal-management/statistics',
        // access: '/complaint/statistics',
      },
    ],
  },
  {
    path: '/logManagement',
    name: '日志管理',
    // access: '/logManagement',
    routes: [
      {
        name: '日志记录',
        path: '/logManagement/list',
        component: './logManagement/index',
        // access: '/logManagement/list',
      },
    ],
  },

];
